sequencetools.repeat_sequence_to_weight_exactly
===============================================

.. autofunction:: abjad.tools.sequencetools.repeat_sequence_to_weight_exactly.repeat_sequence_to_weight_exactly
